==> webgen-1.0.tgz: webgen-1.0/listmain.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 require("authprj.php");
 echo "<h2>ҦMC</h2>";
 /***** {ҥΨ **********/
 $query="select ptab,pname,ctlfile,target,vuser,boards from main";
 $result=db_exec($db_conn,$query);
 if (!$result){
                        echo "Ʈwd߿~AO $query !";
 }
 $numrow=db_NumRows($result);
 if ($numrow==0)
   {
       echo "S!";
   }
 $numfield=db_NumFields($result);
   echo "<table border=1>\n";
   echo "<tr><td>MYg</td><td>W</td><td></td><td>sؿ</td>";
   echo "<td>޲z</td><td>Qװ</td><td>M峹\</td><td>Mק</td></tr>";
 for($a=0;$a<$numrow;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      for ($fpt=0;$fpt<$numfield;$fpt++)
      {
     $ARAW[$fpt]=trim($ARAW[$fpt]);
     if (strstr($ARAW[$fpt],"://")) //URL
     	$special="<a href=\"$ARAW[$fpt]\">".nl2br(htmlspecialchars($ARAW[$fpt]))."</a>";//SrBz
     else
        $special=htmlspecialchars($ARAW[$fpt]);//SrBz
	echo "<td>$special</td>";
      }
      echo "<td>";
      echo "<form method=\"post\" action=\"prj.php\">";
      echo "<input type=\"hidden\" name=\"key\" value=\"$ARAW[0]\">";
      echo "<input type=\"hidden\" name=\"user\" value=\"$user\">";
      echo "<input type=\"submit\" name=\"process\" value=\"[峹\">";
      echo "<input type=\"submit\" name=\"process\" value=\"d\"></form>";
      echo "</td>";
      echo "<td>";
      echo "<form method=\"post\" action=\"process.php\">";
      echo "<input type=\"hidden\" name=\"key\" value=\"$ARAW[0]\">";
      echo "<input type=\"hidden\" name=\"user\" value=\"$user\">";
      echo "<input type=\"submit\" name=\"process\" value=\"ק[c\"></form>";
      echo "</td>";
      echo "</tr>\n";
   }
   echo "</table>\n";
  echo "<a href=\"show.php?cfile=maintain.html&user={$user}\">`޺</a><br>";
  echo "<a href=\"show.php?cfile=passwd.html&user={$user}\">KXק</a><br>";
  echo "<a href=\"show.php?cfile=upload.html&user={$user}\">Wǹɵ</a>";
?>
<!---<a href="sql.html">޳NդHOM</a><br> -->

==> webgen-1.1.tgz: webgen-1.1/listmain.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 require("authprj.php");
 echo "<h2>ҦMC</h2>";
 /***** {ҥΨ **********/
 $query="select ptab,pname,ctlfile,target,vuser,boards from main";
 $result=db_exec($db_conn,$query);
 if (!$result){
                        echo "Ʈwd߿~AO $query !";
 }
 $numrow=db_NumRows($result);
 if ($numrow==0)
   {
       echo "S!";
   }
 $numfield=db_NumFields($result);
   echo "<table border=1>\n";
   echo "<tr><td>MYg</td><td>W</td><td></td><td>sؿ</td>";
   echo "<td>޲z</td><td>Qװ</td><td>M峹\</td><td>Mק</td></tr>";
 for($a=0;$a<$numrow;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      for ($fpt=0;$fpt<$numfield;$fpt++)
      {
     $ARAW[$fpt]=trim($ARAW[$fpt]);
     if (strstr($ARAW[$fpt],"://")) //URL
     	$special="<a href=\"$ARAW[$fpt]\">".nl2br(htmlspecialchars($ARAW[$fpt]))."</a>";//SrBz
     else
        $special=htmlspecialchars($ARAW[$fpt]);//SrBz
	echo "<td>$special</td>";
      }
      echo "<td>";
      echo "<form method=\"post\" action=\"prj.php\">";
      echo "<input type=\"hidden\" name=\"key\" value=\"$ARAW[0]\">";
      echo "<input type=\"hidden\" name=\"user\" value=\"$user\">";
      echo "<input type=\"submit\" name=\"process\" value=\"[峹\">";
      echo "<input type=\"submit\" name=\"process\" value=\"d\"></form>";
      echo "</td>";
      echo "<td>";
      echo "<form method=\"post\" action=\"process.php\">";
      echo "<input type=\"hidden\" name=\"key\" value=\"$ARAW[0]\">";
      echo "<input type=\"hidden\" name=\"user\" value=\"$user\">";
      echo "<input type=\"submit\" name=\"process\" value=\"ק[c\"></form>";
      echo "</td>";
      echo "</tr>\n";
   }
   echo "</table>\n";
  echo "<a href=\"show.php?cfile=maintain.html&user={$user}\">`޺</a><br>";
  echo "<a href=\"show.php?cfile=passwd.html&user={$user}\">KXק</a><br>";
  echo "<a href=\"show.php?cfile=upload.html&user={$user}\">Wǹɵ</a><br>";
  echo "<a href=\"ad.php?user={$user}\">޲zsi</a>";
?>
<!---<a href="sql.html">޳NդHOM</a><br> -->
